# Table of Contents

- [tech-platform-fact-sheet-v3](<./tech-platform-fact-sheet-v3.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Optional Features: Tech Platform Fact Sheet (Meta Model v3)](<./Optional-Features-Tech-Platform-Fact-Sheet-Meta-Model-v3.md>)
  - [Overview](<./Optional-Features-Tech-Platform-Fact-Sheet-Meta-Model-v3/Overview.md>)
  - [Step1: Install Tech Platforms](<./Optional-Features-Tech-Platform-Fact-Sheet-Meta-Model-v3/Step1-Install-Tech-Platforms.md>)
  - [Step 2: Refresh Browser (and wait)](<./Optional-Features-Tech-Platform-Fact-Sheet-Meta-Model-v3/Step-2-Refresh-Browser-and-wait.md>)
  - [Step 3: Define Tech Platforms](<./Optional-Features-Tech-Platform-Fact-Sheet-Meta-Model-v3/Step-3-Define-Tech-Platforms.md>)
  - [Step 4: Connect Tech Platforms with Applications](<./Optional-Features-Tech-Platform-Fact-Sheet-Meta-Model-v3/Step-4-Connect-Tech-Platforms-with-Applications.md>)
  - [Step 5: Add IT Components to Applications](<./Optional-Features-Tech-Platform-Fact-Sheet-Meta-Model-v3/Step-5-Add-IT-Components-to-Applications.md>)
  - [Was this page helpful?](<./Optional-Features-Tech-Platform-Fact-Sheet-Meta-Model-v3/Was-this-page-helpful.md>)
